@@ -27,6 +27,7 @@ import java.util.GregorianCalendar;
 import java.util.TimeZone;
 import java.text.SimpleDateFormat;
 import java.text.ParseException;
+import ts.util.text.StringOperation;
 
 /**
  * \NXB
@@ -58,7 +59,7 @@ import java.text.ParseException;
  * </ul>
  *
  * @author  V. 
- * @version $Revision: 1.2 $, $Date: 2007/02/15 15:28:02 $
+ * @version $Revision: 1.3 $, $Date: 2007/05/27 16:13:05 $
  */
 public class DateTime implements Serializable, Cloneable, Comparable<DateTime>
 {
@@ -901,7 +902,7 @@ public class DateTime implements Serializable, Cloneable, Comparable<DateTime>
 
     SimpleDateFormat fmt;
 
-    int len = str.length();
+    int len = StringOperation.length(str);
     if (len <= 10) {
       fmt = new SimpleDateFormat("yyyy-MM-dd");
     }
