@@ -20,6 +20,8 @@
  */
 package ts.util.resource;
 
+import ts.util.text.StringSequence;
+import ts.util.text.StringOperation;
 import java.io.File;
 import java.io.InputStream;
 import java.io.OutputStream;
@@ -29,6 +31,7 @@ import java.util.List;
 import java.util.ArrayList;
 import java.util.LinkedList;
 import java.util.NoSuchElementException;
+import java.util.Properties;
 import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
 import javax.xml.parsers.ParserConfigurationException;
@@ -36,6 +39,7 @@ import javax.xml.transform.TransformerFactory;
 import javax.xml.transform.Transformer;
 import javax.xml.transform.Source;
 import javax.xml.transform.Result;
+import javax.xml.transform.OutputKeys;
 import javax.xml.transform.dom.DOMSource;
 import javax.xml.transform.stream.StreamResult;
 import org.xml.sax.ErrorHandler;
@@ -96,7 +100,7 @@ import org.w3c.dom.Text;
  *
  *
  * @author  V. 
- * @version $Revision: 1.2 $, $Date: 2007/02/15 15:28:05 $
+ * @version $Revision: 1.3 $, $Date: 2007/05/27 16:13:15 $
  */
 public class XmlResource extends AbstractResource
 {
@@ -175,7 +179,7 @@ public class XmlResource extends AbstractResource
   {
     assert (key != null) : "@param:key is null.";
 
-    if (key.length() == 0) {
+    if (StringOperation.isEmpty(key)) {
       return getBaseNode();
     }
 
@@ -210,6 +214,7 @@ public class XmlResource extends AbstractResource
         continue;
       }
 
+      // for namespace support.
       //if (! n.getNodeName().equals(elemName)) {
       if (! elemName.equals(n.getLocalName())) {
         continue;
@@ -251,7 +256,7 @@ public class XmlResource extends AbstractResource
 
     List<Node> nodeLst = new LinkedList<Node>();
 
-    if (key.length() == 0) {
+    if (StringOperation.isEmpty(key)) {
       nodeLst.add(getBaseNode());
       return nodeLst;
     }
@@ -269,7 +274,6 @@ public class XmlResource extends AbstractResource
    * @param  node  m[hB
    * @param  keyElemLst L[vfXgB 
    * @param  index ݒT̃L[vf̃CfbNXB
-   * @return L[vfXgɊYm[hi[XgB
    * @throws NullPointerException k̏ꍇB
    * @throws IndexOutOfBoundsException CfbNX̒l̏ꍇB
    */
@@ -292,6 +296,7 @@ public class XmlResource extends AbstractResource
         continue;
       }
 
+      // for namespace support.
       //if (! n.getNodeName().equals(elemName)) {
       if (! elemName.equals(n.getLocalName())) {
         continue;
@@ -326,7 +331,7 @@ public class XmlResource extends AbstractResource
   {
     assert (key != null) : "@param:key is null.";
 
-    if (key.length() == 0) {
+    if (StringOperation.isEmpty(key)) {
       return getBaseNode();
     }
 
@@ -377,7 +382,7 @@ public class XmlResource extends AbstractResource
       return "";
     }
 
-    StringBuffer buf = new StringBuffer();
+    StringBuilder buf = new StringBuilder();
 
     NodeList nodeLst = node.getChildNodes();
     if (nodeLst.getLength() > 0) {
@@ -398,13 +403,13 @@ public class XmlResource extends AbstractResource
         switch (n.getNodeType()) {
         case Node.CDATA_SECTION_NODE :
           s = n.getNodeValue();
-          if (s.length() > 0) {
+          if (! StringOperation.isEmpty(s)) {
             buf.append(" ").append(s);
           }
           break;
         case Node.TEXT_NODE :
           s = shortenWhitespace(n.getNodeValue());
-          if (s.length() > 0) {
+          if (! StringOperation.isEmpty(s)) {
             buf.append(" ").append(s);
           }
           break;
@@ -428,36 +433,18 @@ public class XmlResource extends AbstractResource
   {
     assert (s != null) : "@param:s is null.";
 
-    int bgn = s.length();
-    for (int i=0; i<s.length(); i++) {
-      if (! Character.isWhitespace(s.charAt(i))) {
-        bgn = i;
-        break;
-      }
-    }
-
-    int end = 0;
-    for (int i=s.length(); i>bgn; i--) {
-      if (! Character.isWhitespace(s.charAt(i-1))) {
-        end = i;
-        break;
-      }
-    }
-
-    StringBuffer buf = new StringBuffer();
-    boolean isShortened = false;
-    for (int i=bgn; i<end; i++) {
-      char ch = s.charAt(i);
-      if (! Character.isWhitespace(ch)) {
-        buf.append(ch);
-        isShortened = false;
-      }
-      else if (! isShortened) {
+    StringBuilder buf = new StringBuilder(s.length());
+    StringSequence seq = new StringSequence(s).skipWhitespaces();
+    while (seq.validIndex()) {
+      if (seq.index() != seq.skipWhitespaces().index()) {
+        if (! seq.validIndex()) {
+          break;
+        }
         buf.append(" ");
-        isShortened = true;
       }
+      buf.append(seq.character());
+      seq.next();
     }
-
     return buf.toString();
   }
 
@@ -699,7 +686,7 @@ public class XmlResource extends AbstractResource
       }
     }
 
-    if (key.length() == 0) {
+    if (StringOperation.isEmpty(key)) {
       renew();
     }
   }
@@ -790,6 +777,11 @@ public class XmlResource extends AbstractResource
       TransformerFactory factory = TransformerFactory.newInstance();
       Transformer t = factory.newTransformer();
 
+      // ۑt@C̕GR[fBOAǍt@CƓɂ
+      Properties prop = t.getOutputProperties();
+      prop.setProperty(OutputKeys.ENCODING, getDocument().getXmlEncoding());
+      t.setOutputProperties(prop);
+
       Source s = new DOMSource(getBaseNode());
       Result r = new StreamResult(stream);
       t.transform(s, r);
